<?php

namespace App\Http\Controllers\Backend;

use App\Http\Controllers\Controller;
use Illuminate\Http\RedirectResponse;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use Illuminate\View\View;
use App\Models\AboutUs;
use Illuminate\Support\Facades\Storage;
use App\Traits\UploadTrait;
use Illuminate\Contracts\Cache\Store;

class AboutUsController extends Controller
{

    use UploadTrait;

    private $fileUploadLocation = '/uploads/aboutus/';
        /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(): View
    {
        $data['data'] = AboutUs::first();
        if (!empty($data['data'])) {
            $data['action'] = "Edit";
        } else {
            $data['action'] = "Add";
        }
        return view('backend.aboutUs.formAboutUs', $data);
    }

   

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //tags
        $data['action'] = "Add";
        return view('admin.aboutUs.formAboutUs', $data);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $data = request()->validate([
            'banner'=>'',
            'title'=>'',
            'description'=>'',
            'story_title'=>'',
            'story_description'=>'',
            'mission_description'=>'',
            'vision_description'=>'',
            'objectives'=>'',
            'strategies'=>'',
        ]);

        if (request()->hasFile('banner')) {
            $data['banner'] = $this->uploadOne(request()->file('banner'), $this->fileUploadLocation); 
        }
        if (request()->hasFile('first_image')) {
            $data['first_image'] = $this->uploadOne(request()->file('first_image'), $this->fileUploadLocation); 
        }
        if (request()->hasFile('long_image')) {
            $data['long_image'] = $this->uploadOne(request()->file('long_image'), $this->fileUploadLocation); 
        }
        if (request()->hasFile('first_story_image')) {
            $data['first_story_image'] = $this->uploadOne(request()->file('first_story_image'), $this->fileUploadLocation); 
        }
        if (request()->hasFile('second_story_image')) {
            $data['second_story_image'] = $this->uploadOne(request()->file('second_story_image'), $this->fileUploadLocation); 
        }
        if (request()->hasFile('mission_image')) {
            $data['mission_image'] = $this->uploadOne(request()->file('mission_image'), $this->fileUploadLocation); 
        }
        if (request()->hasFile('vision_image')) {
            $data['vision_image'] = $this->uploadOne(request()->file('vision_image'), $this->fileUploadLocation); 
        }
        AboutUs::create($data);

        //Article_tag::insert($insert);
        // if (request()->has('again')) {
        //     return redirect('/myadmin/AboutUs/addAboutUs')->with('success', 'Data has been inserted.');
        // } else {
                return redirect()->route('admin.about-us.index')->with('success','About us page saved successfully.');
        // }
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {

    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //tags
        $data['data'] = AboutUs::first();

        $data['action'] = "Edit";

        return view('backend.aboutUs.formAboutUs', $data);

    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $data = request()->validate([
            'banner'=>'',
            'title'=>'',
            'description'=>'',
            'story_title'=>'',
            'story_description'=>'',
            'mission_description'=>'',
            'vision_description'=>'',
            'objectives'=>'',
            'strategies'=>'',
        ]);

        if (request()->hasFile('banner')) {
            $data['banner'] = $this->uploadOne(request()->file('banner'), $this->fileUploadLocation); 
        }
        if (request()->hasFile('first_image')) {
            $data['first_image'] = $this->uploadOne(request()->file('first_image'), $this->fileUploadLocation);
            if($request->has('old_first_image')){
                if(is_file(public_path(Storage::url($request->old_first_image))))
                unlink(public_path(Storage::url($request->old_first_image)));
            }
        }
        if (request()->hasFile('long_image')) {
            $data['long_image'] = $this->uploadOne(request()->file('long_image'), $this->fileUploadLocation);
            if($request->has('old_long_image')){
                if(is_file(public_path(Storage::url($request->old_long_image))))
                unlink(public_path(Storage::url($request->old_long_image)));
            }
        }
        if (request()->hasFile('first_story_image')) {
            $data['first_story_image'] = $this->uploadOne(request()->file('first_story_image'), $this->fileUploadLocation); 
            if($request->has('old_first_story_image')){
                if(is_file(public_path(Storage::url($request->old_first_story_image))))
                unlink(public_path(Storage::url($request->old_first_story_image)));
            }
        }
        if (request()->hasFile('second_story_image')) {
            $data['second_story_image'] = $this->uploadOne(request()->file('second_story_image'), $this->fileUploadLocation); 
            if($request->has('old_second_story_image')){
                if(is_file(public_path(Storage::url($request->old_second_story_image))))
                unlink(public_path(Storage::url($request->old_second_story_image)));
            }
        }
        if (request()->hasFile('mission_image')) {
            $data['mission_image'] = $this->uploadOne(request()->file('mission_image'), $this->fileUploadLocation);
            if($request->has('old_mission_image')){
                if(is_file(public_path(Storage::url($request->old_mission_image))))
                unlink(public_path(Storage::url($request->old_mission_image)));
            }
        }
        if (request()->hasFile('vision_image')) {
            $data['vision_image'] = $this->uploadOne(request()->file('vision_image'), $this->fileUploadLocation);
            if($request->has('old_vision_image')){
                if(is_file(public_path(Storage::url($request->old_vision_image))))
                unlink(public_path(Storage::url($request->old_vision_image)));
            }
        }

        $update = AboutUs::where('id', $id)->update($data);
        return redirect()->route('admin.about-us.index')->with('success','About Us page saved successfully.');

        // if (request()->has('again') && request()->input('again') == '1') {
        //     return redirect('/myadmin/AboutUs/editAboutUs/' . $id)->with('success', 'Data has been Updated.');
        // } else {
        //     return redirect('/myadmin/AboutUs')->with('success', 'Data has been Updated.');
        // }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
}
