<?php

namespace App\Http\Controllers\Backend;

use App\Helpers\GeneralHelper;
use App\Http\Controllers\Controller;

use App\Models\Album;
use App\Models\Academic;
use App\Models\AcademicCategory;
use App\Models\Photo;
use App\Traits\UploadTrait;
use Illuminate\Http\JsonResponse;
use Illuminate\Http\Request;
use Illuminate\Http\Resources\Json\JsonResource;

class AcademicController extends Controller
{
    use UploadTrait;

    private $fileUploadLocation = '/uploads/academic/';

    public function index(){
        $data = Academic::get();
        return view('backend.academic.index',['data' => $data]);
    }

    public function show(Academic $academic){
        $data['category'] = AcademicCategory::where('active',1)->orderBy('sort_order','ASC')->get();
        $data['data'] = $academic;
        return view('backend.academic.show',$data);
    }

    public function create(){
        $data['category'] = AcademicCategory::where('active',1)->orderBy('sort_order','ASC')->get();
        return view('backend.academic.add',$data);
    }

    public function store(Request $request){

        $data = $request->validate([
            'category_id' => 'sometimes|nullable',
            'title' => 'required|string|max:255',
            'first_description' => 'required',
            'second_description' => 'sometimes|nullable',
            'first_image' => 'sometimes|nullable|mimes:jpg,bmp,png,jpeg',
            'second_image' => 'sometimes|nullable|mimes:jpg,bmp,png,jpeg',
            'third_image' => 'sometimes|nullable|mimes:jpg,bmp,png,jpeg',
            'fourth_image' => 'sometimes|nullable|mimes:jpg,bmp,png,jpeg',
            'sort_order' => 'sometimes|nullable'
        ]);

        $data['sort_order'] = request()->sort_order??1;
        $data['slug'] = $this->generate_slug($data['title']);
        if (request()->has('active')) {
            $data['active'] = @request()->active?'1':'0';
        }else{
            $data['active'] = 0;
        }
        if (request()->hasFile('first_image')) {
            $data['first_image'] = $this->uploadFile(request()->file('first_image'), $this->fileUploadLocation);
        }
        if (request()->hasFile('second_image')) {
            $data['second_image'] = $this->uploadFile(request()->file('second_image'), $this->fileUploadLocation);
        }
        if (request()->hasFile('third_image')) {
            $data['third_image'] = $this->uploadFile(request()->file('third_image'), $this->fileUploadLocation);
        }
        if (request()->hasFile('fourth_image')) {
            $data['fourth_image'] = $this->uploadFile(request()->file('fourth_image'), $this->fileUploadLocation);
        }
        Academic::create($data);
        return redirect()->route('admin.academics.index')->with('success','Academic Program created successfully.');
    }

    public function edit(Academic $academic)
    {
        $data['category'] = AcademicCategory::where('active',1)->orderBy('sort_order','ASC')->get();
        $data['data'] = $academic;
        return view('backend.academic.edit',$data);
    }

    public function update(Request $request,$id)
    {
        $data = $request->validate([
            'category_id' => 'sometimes|nullable',
            'title' => 'required|string|max:255',
            'first_description' => 'required',
            'second_description' => 'sometimes|nullable',
            'first_image' => 'sometimes|nullable|mimes:jpg,bmp,png,jpeg',
            'second_image' => 'sometimes|nullable|mimes:jpg,bmp,png,jpeg',
            'third_image' => 'sometimes|nullable|mimes:jpg,bmp,png,jpeg',
            'fourth_image' => 'sometimes|nullable|mimes:jpg,bmp,png,jpeg',
            'sort_order' => 'sometimes|nullable'
        ]);
        $data['sort_order'] = request()->sort_order??1;
        $data['slug'] = $this->generate_slug($data['title']);

        if (request()->has('active')) {
            $data['active'] = @request()->active?'1':'0';
        }else{
            $data['active'] = 0;
        }

        if (request()->hasFile('first_image')) {
            $data['first_image'] = $this->uploadFile(request()->file('first_image'), $this->fileUploadLocation);
              // if($request->has('old_file')){
            //     if(is_file(Storage::url($request->old_file)))
            //     Storage::delete($request->old_file);
            // }
        }
        if (request()->hasFile('second_image')) {
            $data['second_image'] = $this->uploadFile(request()->file('second_image'), $this->fileUploadLocation);
        }
        if (request()->hasFile('third_image')) {
            $data['third_image'] = $this->uploadFile(request()->file('third_image'), $this->fileUploadLocation);
        }
        if (request()->hasFile('fourth_image')) {
            $data['fourth_image'] = $this->uploadFile(request()->file('fourth_image'), $this->fileUploadLocation);
        }
        if (request()->hasFile('file')) {
            $request->validate([
                'file' => 'mimes:jpg,bmp,png,jpeg,doc,docx,xls,xlsx,pdf'
            ]);
            $data['file'] = $this->uploadOne(request()->file('file'), $this->fileUploadLocation);
        }
        Academic::where('id',$id)->update($data);
        return redirect()->route('admin.academics.index')->with('success','Academic program has been updated successfully.');
        // return redirect()->route('manageAlbums')->with('success', 'Album updated successfully');
    }

    public function destroy($id)
    {
        Academic::where('id',$id)->delete();
        return redirect()->route('admin.academics.index')->with('success','Academic program has been deleted successfully.');
    }

    // public function getAlbumImages($albumId){
    //     $photos = Photo::where('album_id',$albumId)->orderBy('clickedDate', 'asc')->get();
    //     $album = AcademicCategory::where('id',$albumId)->first();
    //     return view('photos.managePhotos',compact('photos','albumId','album'));
    // }


    // public function getAllAlbums():JsonResponse{
    //     $albums = AcademicCategory::all();
    //     return response()->json(['albums'=>$albums]);
    // }

    // public function getAlbumWithPhotos($albumId):JsonResponse{
    //     $album = AcademicCategory::with('photos')->find($albumId);
    //     if(!$album){
    //         return response()->json(['error'=>'Album not found']);
    //     }
    //     return response()->json(['album'=>$album]);
    // }

    private function generate_slug($str)
    {
        $pageName = GeneralHelper::slugify($str);
        return $pageName;

    }
}
