<?php

namespace App\Http\Controllers\Backend;

use App\Http\Controllers\Controller;

use App\Models\Banner;
use Illuminate\Http\RedirectResponse;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use Illuminate\View\View;
use Illuminate\Support\Facades\Storage;
use App\Traits\UploadTrait;
use Illuminate\Contracts\Cache\Store;

class BannerController extends Controller
{

    use UploadTrait;

    private $fileUploadLocation = '/uploads/banner/';
        /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(): View
    {
        $data['data'] = Banner::get();
        return view('backend.banner.index', $data);
    }

   

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('backend.banner.add');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $data = request()->validate([
            'title' => '',
            'description' => '',
            'button_link' => '',
            'alt_button_link' => '',
            'image' => 'required',
            // 'show_form' => 'required',
            'sort_order' => '',
            // 'active' => ''
        ]);
        $data['sort_order'] = request()->sort_order??1;

        if (request()->has('show_form')) {
            $data['show_form'] = @request()->show_form?'1':'0';
        }else{
            $data['show_form'] = 0;
        }
        
        if (request()->has('active')) {
            $data['active'] = @request()->active?'1':'0';
        }else{
            $data['active'] = 0;
        }

        if (request()->hasFile('image')) {
            $data['image'] = $this->uploadOne(request()->file('image'), $this->fileUploadLocation); 
        }
        Banner::create($data);

        // if (request()->has('again')) {
        //     return redirect('/myadmin/generalsettings/addGeneralsettings')->with('success', 'Data has been inserted.');
        // } else {
                return redirect()->route('admin.banner.index')->with('success','New Banner created successfully.');
        // }
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show(Banner $banner)
    {
        return view('backend.banner.show',['data' => $banner]);

    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(Banner $banner)
    {
        return view('backend.banner.edit',['data' => $banner]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $data = request()->validate([
            'title' => '',
            'description' => '',
            'button_link' => '',
            'alt_button_link' => '',
            'image' => '',
            // 'show_form' => 'required',
            'sort_order' => '',
            // 'active' => ''
        ]);
        if (request()->has('sort_order')) {
            $data['sort_order'] = request()->sort_order??1;
        }

        if (request()->has('show_form')) {
            $data['show_form'] = @request()->show_form?'1':'0';
        }else{
            $data['show_form'] = 0;
        }
        
        if (request()->has('active')) {
            $data['active'] = @request()->active?'1':'0';
        }else{
            $data['active'] = 0;
        }

        if (request()->hasFile('image')) {
            $request->validate([
                'image' => 'mimes:jpg,bmp,png,jpeg'
            ]);
            $data['image'] = $this->uploadOne(request()->file('image'), $this->fileUploadLocation); 
            if($request->has('old_image')){
                if(is_file(public_path(Storage::url($request->old_logo))))
                    unlink(public_path(Storage::url($request->old_logo)));
            }
        }

        $update = Banner::where('id', $id)->update($data);
        return redirect()->route('admin.banner.index')->with('success','Banner updated successfully.');

        // if (request()->has('again') && request()->input('again') == '1') {
        //     return redirect('/myadmin/generalsettings/editGeneralsettings/' . $id)->with('success', 'Data has been Updated.');
        // } else {
        //     return redirect('/myadmin/generalsettings')->with('success', 'Data has been Updated.');
        // }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Banner $banner)
    {
        if(is_file(public_path(Storage::url($banner->image))))
            unlink(public_path(Storage::url($banner->image)));
        $banner->delete();
        return redirect()->route('admin.banner.index')->with('success','Banner has been deleted successfully.');
    }
}
