<?php

namespace App\Http\Controllers\Backend;

use App\Http\Controllers\Controller;
use App\Models\Metatag;
use Illuminate\Http\Request;
use App\Traits\UploadTrait;
use Illuminate\View\View;

class MetatagController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    use UploadTrait;

    private $fileUploadLocation = '/uploads/metatags/';
        /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(): View
    {
        $data['data'] = Metatag::get();
        return view('backend.metatags.index', $data);
    }
    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('backend.metatags.add');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $data = $request->validate([
            'title' => 'required|string|max:255',
            'description' => 'required',
            'image' => 'required|mimes:jpg,bmp,png,jpeg',
            'canonical' => 'required'
        ]);

        if (request()->hasFile('image')) {
            $data['image'] = $this->uploadOne(request()->file('image'), $this->fileUploadLocation);
        }

        Metatag::create($data);
                return redirect()->route('admin.metatags.index')->with('success','New Metatag created successfully.');
    }

    /**
     * Display the specified resource.
     */
    public function show(Metatag $metatag)
    {
        return view('backend.metatags.show',['data' => $metatag]);
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(Metatag $metatag)
    {
        return view('backend.metatags.edit',['data' => $metatag]);
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, $id)
    {
        $data = $request->validate([
           'title' => 'required|string|max:255',
            'description' => 'required',
            'canonical' => 'required'
        ]);

        if (request()->hasFile('image')) {
            $request->validate([
                'image' => 'mimes:jpg,bmp,png,jpeg'
            ]);
            $data['image'] = $this->uploadOne(request()->file('image'), $this->fileUploadLocation);

        }

        $update = Metatag::where('id', $id)->update($data);
        return redirect()->route('admin.metatags.index')->with('success','Metatag updated successfully.');
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Metatag $metatag)
    {
        // if (Storage::exists($this->fileUploadLocation . $metatag->image)) {
        //     Storage::delete($this->fileUploadLocation . $metatag->image);
        // }

        $metatag->delete();
        return redirect()->route('admin.metatags.index')->with('success','Metatag has been deleted successfully.');
    }
}
