<?php

namespace App\Http\Controllers\Backend;

use App\Http\Controllers\Controller;
use App\Models\Notice;
use App\Traits\UploadTrait;
use Illuminate\Http\Request;
use Illuminate\View\View;
use App\Helpers\GeneralHelper;

class NoticeController extends Controller
{
    use UploadTrait;

    private $fileUploadLocation = '/uploads/notices/';
        /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(): View
    {
        $data['data'] = Notice::get();
        return view('backend.notices.index', $data);
    }
    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('backend.notices.add');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $data = request()->validate([
            'title' => 'required',
            'first_description' => '',
            'second_description' => '',
            'image' => 'required|mimes:jpg,bmp,png,jpeg,pdf',
            'published_date' => 'required'
        ]);
        $data['slug'] = $this->generate_slug($data['title']);
        $data['sort_order'] = request()->sort_order??1;
        if (request()->has('active')) {
            $data['active'] = @request()->active?'1':'0';
        }else{
            $data['active'] = 0;
        }
        if (request()->hasFile('image')) {
            if(request()->file('image')->getClientMimeType() == 'application/pdf'){
                $data['image'] = $this->uploadFile(request()->file('image'), $this->fileUploadLocation);
                $data['is_pdf'] = 1;
            }else{
                $data['image'] = $this->uploadOne(request()->file('image'), $this->fileUploadLocation);
                $data['is_pdf'] = 0;
            }
        }
        Notice::create($data);
                return redirect()->route('admin.notices.index')->with('success','New Notices created successfully.');
    }

    /**
     * Display the specified resource.
     */
    public function show(Notice $notice)
    {
        return view('backend.notices.show',['data' => $notice]);
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(Notice $notice)
    {
        return view('backend.notices.edit',['data' => $notice]);
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, $id)
    {
        $data = request()->validate([
            'title' => 'required',
            'first_description' => '',
            'second_description' => '',
            'published_date' => 'required'
        ]);
        $data['slug'] = $this->generate_slug($data['title']);
        $data['sort_order'] = request()->sort_order??1;
        if (request()->has('active')) {
            $data['active'] = @request()->active?'1':'0';
        }else{
            $data['active'] = 0;
        }
        if (request()->hasFile('image')) {
            $request->validate([
                'image' => 'mimes:jpg,bmp,png,jpeg,pdf'
            ]);
            if(request()->file('image')->getClientMimeType() == 'application/pdf'){
                $data['image'] = $this->uploadFile(request()->file('image'), $this->fileUploadLocation);
                $data['is_pdf'] = 1;
            }else{
                $data['image'] = $this->uploadOne(request()->file('image'), $this->fileUploadLocation);
                $data['is_pdf'] = 0;
            }
        }

        $update = Notice::where('id', $id)->update($data);
        return redirect()->route('admin.notices.index')->with('success','Notices updated successfully.');
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Notice $notice)
    {

        $notice->delete();
        return redirect()->route('admin.notices.index')->with('success','notices has been deleted successfully.');
    }

    private function generate_slug($str)
    {
        $pageName = GeneralHelper::slugify($str);
        return $pageName;
    }
}
