<?php

namespace App\Http\Controllers\Backend;

use App\Helpers\GeneralHelper;
use App\Http\Controllers\Controller;

use App\Models\Album;
use App\Models\Qaa;
use App\Models\Photo;
use App\Traits\UploadTrait;
use Illuminate\Http\JsonResponse;
use Illuminate\Http\Request;
use Illuminate\Http\Resources\Json\JsonResource;
use Illuminate\Support\Facades\Storage;

class QaaController extends Controller
{
    use UploadTrait;

    private $fileUploadLocation = '/uploads/downloads/';

    public function index(){
        $data = Qaa::get();
        return view('backend.qaa.index',['data' => $data]);
    }

    public function show(){
        return view('backend.download');
    }

    public function create(){
        return view('backend.qaa.add');
    }

    public function store(Request $request){
        $data = $request->validate([
            'title' => 'required|string|max:255',
            'file' => 'required|mimes:jpg,bmp,png,jpeg,doc,docx,xls,xlsx,pdf',
            'uploaded_date' => 'required',
            'sort_order' => ''
        ]);
        $data['slug'] = $this->generate_slug($data['title']);

        $data['sort_order'] = request()->sort_order??1;

        if (request()->has('active')) {
            $data['active'] = @request()->active?'1':'0';
        }else{
            $data['active'] = 0;
        }
        if (request()->hasFile('file')) {
            $data['file'] = $this->uploadFile(request()->file('file'), $this->fileUploadLocation);
        }
        Qaa::create($data);
        return redirect()->route('admin.qaa.index')->with('success','Qaa file created successfully.');
    }

    public function edit(Qaa $qaa)
    {
        $data['data'] = $qaa;
        return view('backend.qaa.edit',$data);
    }

    public function update(Request $request,$id)
    {
        $data = $request->validate([
            'title' => 'required|string|max:255',
            'file' => 'mimes:jpg,bmp,png,jpeg,doc,docx,xls,xlsx,pdf',
            'uploaded_date' => 'required',
            'sort_order' => ''
        ]);
        $data['sort_order'] = request()->sort_order??1;
        $data['slug'] = $this->generate_slug($data['title']);

        if (request()->has('active')) {
            $data['active'] = @request()->active?'1':'0';
        }else{
            $data['active'] = 0;
        }

        if (request()->hasFile('file')) {
            $request->validate([
                'file' => 'mimes:jpg,bmp,png,jpeg,doc,docx,xls,xlsx,pdf'
            ]);
            $data['file'] = $this->uploadOne(request()->file('file'), $this->fileUploadLocation);
            if($request->has('old_image')){
                if(is_file(public_path(Storage::url($request->old_file))))
                    unlink(public_path(Storage::url($request->old_file)));
            }
        }
        Qaa::where('id',$id)->update($data);
        return redirect()->route('admin.qaa.index')->with('success','Qaa file has been updated successfully.');
        // return redirect()->route('manageAlbums')->with('success', 'Album updated successfully');
    }

    public function destroy($id)
    {
        $data = Qaa::where('id',$id)->first();
        if(is_file(public_path(Storage::url($data->file))))
            unlink(public_path(Storage::url($data->file)));
        $data->delete();
        return redirect()->route('admin.qaa.index')->with('success','Qaa file has been deleted successfully.');
    }

    private function generate_slug($str)
    {
        $pageName = GeneralHelper::slugify($str);
        return $pageName;
    }

    // public function getAlbumImages($albumId){
    //     $photos = Photo::where('album_id',$albumId)->orderBy('clickedDate', 'asc')->get();
    //     $album = DownloadCategory::where('id',$albumId)->first();
    //     return view('photos.managePhotos',compact('photos','albumId','album'));
    // }


    // public function getAllAlbums():JsonResponse{
    //     $albums = DownloadCategory::all();
    //     return response()->json(['albums'=>$albums]);
    // }

    // public function getAlbumWithPhotos($albumId):JsonResponse{
    //     $album = DownloadCategory::with('photos')->find($albumId);
    //     if(!$album){
    //         return response()->json(['error'=>'Album not found']);
    //     }
    //     return response()->json(['album'=>$album]);
    // }
}
