<?php

namespace App\Http\Controllers\Backend;

use App\Helpers\GeneralHelper;
use App\Http\Controllers\Controller;
use App\Models\Team;
use App\Traits\UploadTrait;
use Illuminate\Http\Request;
use Illuminate\View\View;

class TeamController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    // public function index()
    // {
    //     //
    // }
    use UploadTrait;

    private $fileUploadLocation = '/uploads/teams/';
        /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(): View
    {
        $data['data'] = Team::get();
        return view('backend.teams.index', $data);
    }
    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('backend.teams.add');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $data = request()->validate([
            'name' => 'required',
            'designation' => 'required',
            'image' => 'required|mimes:jpg,bmp,png,jpeg',
            'email' => 'required|email',
            'phone' => 'required|integer',
            'team_type' => 'required',
        ]);
        $data['sort_order'] = request()->sort_order??1;
        if (request()->has('active')) {
            $data['active'] = @request()->active?'1':'0';
        }else{
            $data['active'] = 0;
        }
        if ($request->team_type == 'Faculty') {
            $data['team_level'] = $request->validate([
                'team_level' => 'required|string',
            ])['team_level'];
        } else {
            $data['team_level'] = null;
        }
        $data['slug'] = $this->generate_slug($data['name']);

        if (request()->hasFile('image')) {
            $data['image'] = $this->uploadOne(request()->file('image'), $this->fileUploadLocation);
        }
        Team::create($data);
                return redirect()->route('admin.teams.index')->with('success','New Teams created successfully.');
    }

    /**
     * Display the specified resource.
     */
    public function show(Team $team)
    {
        return view('backend.teams.show',['data' => $team]);
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(Team $team)
    {
        return view('backend.teams.edit',['data' => $team]);
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, $id)
    {
        $data = request()->validate([
            'name' => 'required',
            'designation' => 'required',
            'email' => 'required|email',
            'phone' => 'required|integer',
            'team_type' => 'required',
        ]);
        $data['sort_order'] = request()->sort_order??1;
        if (request()->has('active')) {
            $data['active'] = @request()->active?'1':'0';
        }else{
            $data['active'] = 0;
        }
        if ($request->team_type == 'Faculty') {
            $request->validate([
                'team_level' => 'required',
            ]);
            $data['team_level'] = $request->team_level;
        } else {
            $data['team_level'] = null; // Optional: Set to null if not Faculty
        }
        $data['slug'] = $this->generate_slug($data['name']);

        if (request()->hasFile('image')) {
            $request->validate([
                'image' => 'mimes:jpg,bmp,png,jpeg'
            ]);
            $data['image'] = $this->uploadOne(request()->file('image'), $this->fileUploadLocation);

        }

        $update = Team::where('id', $id)->update($data);
        return redirect()->route('admin.teams.index')->with('success','Teams updated successfully.');
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Team $team)
    {
        //     if(file_exists(Storage::url($teams->image)))
        //     Storage::delete($teams->image);
        $team->delete();
        return redirect()->route('admin.teams.index')->with('success','teams has been deleted successfully.');
    }

    private function generate_slug($str)
    {
        $pageName = GeneralHelper::slugify($str);
        return $pageName;
    }
}
