<?php

namespace App\Http\Controllers\Frontend;

use App\Http\Controllers\Controller;
use App\Models\AboutUs;
use App\Models\Academic;
use App\Models\Album;
use App\Models\Banner;
use App\Models\Chairman;
use App\Models\Download;
use App\Models\DownloadCategory;
use App\Models\Event;
use App\Models\Facility;
use App\Models\Faq;
use App\Models\Metatag;
use App\Models\News;
use App\Models\Notice;
use App\Models\OrganizationStructure;
use App\Models\Qaa;
use App\Models\Service;
use App\Models\Team;
use App\Models\Testimonial;
use Illuminate\Http\RedirectResponse;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\File;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Storage;
use Illuminate\View\View;

class FrontendController extends Controller
{
    /**
     * Display the user's profile form.
     */
    public function home(): View
    {
        $data['banners'] = Banner::where('active',1)->orderBy('show_form','DESC')->orderBy('sort_order','ASC')->get();
        $data['chairman'] = Chairman::select('image','description','name')->first();
        $data['about'] = AboutUs::select('title','description','first_image','long_image')->first();
        $data['news'] = News::where('active',1)->orderBy('sort_order','ASC')->orderBy('published_date','DESC')->take(3)->get();
        $data['faqs'] = Faq::where('active',1)->orderBy('sort_order','ASC')->take(4)->get();
        $data['events'] = Event::where('active',1)->orderBy('sort_order','ASC')->orderBy('event_date','DESC')->take(4)->get();
        $data['testimonials'] = Testimonial::where('active',1)->orderBy('sort_order','ASC')->take(3)->get();
        $data['metatag']= Metatag::first();
        return view('frontend.home',$data);
    }

    public function about(): View
    {
        $data['about'] = AboutUs::first();
        $data['metatag']= Metatag::first();

        return view('frontend.about',$data);
    }

    public function chairman(): View
    {
        $data['chairman'] = Chairman::first();
        $data['metatag']= Metatag::first();

        return view('frontend.chairman',$data);
    }

    public function team(): View
    {
        $data['team'] = Team::where('active',1)->orderBy('sort_order','ASC')->get();
        $data['metatag']= Metatag::first();

        return view('frontend.team',$data);
    }

    public function facilities(): View
    {
        $data['facilities'] = Facility::first();
        $data['services'] = Service::where('active',1)->orderBy('sort_order','ASC')->get();
        $data['metatag']= Metatag::first();

        return view('frontend.facilities',$data);
    }

    public function singleFacility($slug): View
    {
        $data['facility'] = Service::where('slug',$slug)->first();
        $data['metatag']= Metatag::first();

        return view('frontend.single-facility',$data);
    }

    public function organization(): View
    {
        $data['organization'] = OrganizationStructure::first();
        return view('frontend.organization-structure',$data);
    }

    public function academic($slug): View
    {
        $data['program'] = Academic::where('slug',$slug)->first();
        $data['metatag']= Metatag::first();

        return view('frontend.academic',$data);
    }

    public function newslist(): View
    {
        $data['newslist'] = News::get();
        $data['metatag']= Metatag::first();

        return view('frontend.news',$data);
    }

    public function singleNews($slug): View
    {
        $data['news'] = News::where('slug',$slug)->first();
        $data['metatag']= Metatag::first();

        return view('frontend.singlenews',$data);
    }

    public function gallery(): View
    {
        $data['gallery'] = Album::whereHas('photos')->withCount('photos')->with('photos','coverPhoto')->get();
        $data['metatag']= Metatag::first();

        return view('frontend.gallery',$data);
    }

    public function singleGallery($slug): View
    {
        $data['metatag']= Metatag::first();
        $data['gallery'] = Album::where('slug',$slug)->with('photos')->first();
        return view('frontend.singlegallery',$data);
    }

    public function downloads(){
        $data['download_category'] = DownloadCategory::get();
        $data['downloads'] = Download::get();
        $data['metatag']= Metatag::first();

        return view('frontend.downloads',$data);

    }

    public function contact(){
        $data['metatag']= Metatag::first();

        return view('frontend.contact',$data);
    }

    public function enroll(){
        $data['metatag']= Metatag::first();

        return view('frontend.enroll',$data);
    }

    public function faq(){
        $data['faqs'] = Faq::get();
        $data['metatag']= Metatag::first();

        return view('frontend.faq',$data);
    }

    public function events(){
        $data['events'] = Event::orderBy('sort_order','ASC')->orderBy('event_date','DESC')->get();
        // dd($data);
        $data['metatag']= Metatag::first();

        return view('frontend.events',$data);
    }

    public function singleEvent($slug){
        $data['event'] = Event::where('slug',$slug)->first();
        $data['metatag']= Metatag::first();

        return view('frontend.single-event',$data);
    }

    public function notice(){
        $data['notice'] = Notice::where('active',1)->orderBy('sort_order','ASC')->orderBy('published_date','DESC')->get();
        $data['metatag']= Metatag::first();

        return view('frontend.notice',$data);
    }

    public function singleNotice($slug){
        $data['notice'] = Notice::where('active',1)->where('slug',$slug)->first();
        if(!$data['notice']){
            abort(404);
        }
        $data['metatag']= Metatag::first();

        return view('frontend.single-notice',$data);

    }

    public function qaa($slug){
        $data['qaa'] = Qaa::where('slug',$slug)->first();
        $data['metatag']= Metatag::first();

        return view('frontend.qaa',$data);
    }


    public function downloadFile()
    {
        $url = request()->file;
        $name = request()->name;
        $file_path = public_path(Storage::url($url));
        $file_name = $name;

        return response()->download($file_path, $file_name);
    }
}
